dat.hughes: A Meta-Analysis on the Effects of Ovulation Suppression for...

dat.hughesR Documentation

A Meta-Analysis on the Effects of Ovulation Suppression for Endometriosis in Subfertile Women

Description

This meta-analysis serves as an example to illustrate the usage of the function metahet.hybrid.

Usage

data("dat.hughes")

Format

A data frame containing 11 studies.

y

the observed effect size (log odds ratio) for each study in the meta-analysis.

s2

the within-study variance for each study.

Hughes E, Brown J, Collins JJ, et al. (2007). "Ovulation suppression for endometriosis for women with subfertility." Cochrane Database of Systematic Reviews, 7. Art. No.: CD000155. <\Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/14651858.CD000155.pub2")}>


altmeta documentation built on April 30, 2026, 9:08 a.m.

Related to dat.hughes in altmeta...