Learn R Programming

altmeta (version 4.4)

dat.sherrington: A Meta-Analysis on the Effects of Exercise Interventions for Preventing Falls in Older People

Description

This meta-analysis serves as an example to illustrate the usage of the function pb.timelag.

Usage

data("dat.sherrington")

Arguments

Format

A data frame containing 19 studies.

study

the study label for each study in the meta-analysis.

year

the publication year for each study.

yi

the observed effect size (log rate ratio) for each study in the meta-analysis.

vi

the within-study variance for each study.

n1

the sample size in the exercise intervention group.

n2

the sample size in the control group.