hipfrac: A Meta-Analysis for Investigating the Magnitude and Duration of Excess Mortality After Hip Fracture Among Older Men
Description
This meta-analysis serves as an example to illustrate the function usage in the package altmeta.
Usage
data("hipfrac")
Arguments
source
Haentjens P, Magaziner J, Colon-Emeric CS, Vanderschueren D, Milisen K, Velkeniers B, and Boonen S (2010). "Meta-analysis: excess mortality after hip fracture among older women and men". Annals of Internal Medicine, 152(6), 380--390.