This meta-analysis serves as an example to illustrate the usage of the function pb.timelag.
data("dat.sherrington")A data frame containing 19 studies.
studythe study label for each study in the meta-analysis.
yearthe publication year for each study.
yithe observed effect size (log rate ratio) for each study in the meta-analysis.
vithe within-study variance for each study.
n1the sample size in the exercise intervention group.
n2the sample size in the control group.