metaoutliers(y, s2, model)"FE" or "RE". If model = "FE", this function uses the outlier detection procedure for fixed-effect meta-analysis desribed in Hedges and Olkin (1985) Chapter 12; If model = "FE"). Using the studies except study $i$, the pooled estimate of overall effect size is $\bar{\mu}_{(-i)} = \sum_{j \neq i} w_j y_j / \sum_{j \neq i} w_j$. The residual of study $i$ is $e_{i} = y_i - \bar{\mu}_{(-i)}$. The variance of $e_{i}$ is $v_{i} = s_{i}^{2} + (\sum_{j \neq i} w_{j})^{-1}$, so the standardized residual of study $i$ is $\epsilon_{i} = e_{i} / \sqrt{v_{i}}$.
Viechtbauer and Cheung (2010) describes the outlier detection procedure for random-effects meta-analysis (model = "RE"). Using the studies except study $i$, let the method-of-moments estimate of between-study variance be $\hat{\tau}_{(-i)}^{2}$. The pooled estimate of overall effect size is $\bar{\mu}_{(-i)} = \sum_{j \neq i} \tilde{w}_{(-i)j} y_j / \sum_{j \neq i} \tilde{w}_{(-i)j}$, where $\tilde{w}_{(-i)j} = 1/(s_{j}^{2} + \hat{\tau}_{(-i)}^{2})$. The residual of study $i$ is $e_{i} = y_i - \bar{\mu}_{(-i)}$, and its variance is $v_{i} = s_{i}^2 + \hat{\tau}_{(-i)}^{2} + (\sum_{j \neq i} \tilde{w}_{(-i)j})^{-1}$. Then, the standardized residual of study $i$ is $\epsilon_{i} = e_{i} / \sqrt{v_{i}}$.data("aex")
attach(aex)
metaoutliers(y, s2, model = "FE")
metaoutliers(y, s2, model = "RE")
detach(aex)
data("hipfrac")
attach(hipfrac)
metaoutliers(y, s2)
detach(hipfrac)Run the code above in your browser using DataLab